# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ncbi_datasets_util',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/ncbi_datasets_util',
                'lib_path': 'ncbi_datasets_util'},
  'syms': { 'ncbi_datasets_util.core': { 'ncbi_datasets_util.core.DnaSeq': ('core.html#dnaseq', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.__add__': ( 'core.html#dnaseq.__add__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.__init__': ( 'core.html#dnaseq.__init__',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.__iter__': ( 'core.html#dnaseq.__iter__',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.__len__': ( 'core.html#dnaseq.__len__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.__repr__': ( 'core.html#dnaseq.__repr__',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.iupac_counts': ( 'core.html#dnaseq.iupac_counts',
                                                                                          'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.phred_score_to_int': ( 'core.html#dnaseq.phred_score_to_int',
                                                                                                'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.print_fasta': ( 'core.html#dnaseq.print_fasta',
                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.reverse_complement': ( 'core.html#dnaseq.reverse_complement',
                                                                                                'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.DnaSeq.translate': ( 'core.html#dnaseq.translate',
                                                                                       'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta': ('core.html#fasta', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.__init__': ( 'core.html#fasta.__init__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.__iter__': ( 'core.html#fasta.__iter__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.__len__': ('core.html#fasta.__len__', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.__repr__': ( 'core.html#fasta.__repr__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.concat_seq': ( 'core.html#fasta.concat_seq',
                                                                                       'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.from_file': ( 'core.html#fasta.from_file',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.iupac_counts': ( 'core.html#fasta.iupac_counts',
                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fasta.write': ('core.html#fasta.write', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq': ('core.html#fastq', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.__init__': ( 'core.html#fastq.__init__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.__iter__': ( 'core.html#fastq.__iter__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.__len__': ('core.html#fastq.__len__', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.__repr__': ( 'core.html#fastq.__repr__',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.from_file': ( 'core.html#fastq.from_file',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.Fastq.write': ('core.html#fastq.write', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.NcbiDataSummarizer': ( 'core.html#ncbidatasummarizer',
                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.NcbiDataSummarizer.get_files_from_data_folder': ( 'core.html#ncbidatasummarizer.get_files_from_data_folder',
                                                                                                                    'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.NcbiDataSummarizer.get_files_from_isolate_folder': ( 'core.html#ncbidatasummarizer.get_files_from_isolate_folder',
                                                                                                                       'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.NcbiDataSummarizer.summarize_data_folder': ( 'core.html#ncbidatasummarizer.summarize_data_folder',
                                                                                                               'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.NcbiDataSummarizer.summarize_fasta': ( 'core.html#ncbidatasummarizer.summarize_fasta',
                                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinFasta': ('core.html#proteinfasta', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinFasta.__init__': ( 'core.html#proteinfasta.__init__',
                                                                                            'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinFasta.from_file': ( 'core.html#proteinfasta.from_file',
                                                                                             'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq': ('core.html#proteinseq', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.__add__': ( 'core.html#proteinseq.__add__',
                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.__init__': ( 'core.html#proteinseq.__init__',
                                                                                          'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.__iter__': ( 'core.html#proteinseq.__iter__',
                                                                                          'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.__len__': ( 'core.html#proteinseq.__len__',
                                                                                         'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.__repr__': ( 'core.html#proteinseq.__repr__',
                                                                                          'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.ProteinSeq.print_to_file': ( 'core.html#proteinseq.print_to_file',
                                                                                               'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.SpadesAssembly': ( 'core.html#spadesassembly',
                                                                                     'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.SpadesAssembly.contig_stats': ( 'core.html#spadesassembly.contig_stats',
                                                                                                  'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.SpadesAssembly.filter_contigs': ( 'core.html#spadesassembly.filter_contigs',
                                                                                                    'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.get_config': ('core.html#get_config', 'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.get_samplesheet': ( 'core.html#get_samplesheet',
                                                                                      'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.set_env_variables': ( 'core.html#set_env_variables',
                                                                                        'ncbi_datasets_util/core.py'),
                                         'ncbi_datasets_util.core.show_project_env_vars': ( 'core.html#show_project_env_vars',
                                                                                            'ncbi_datasets_util/core.py')},
            'ncbi_datasets_util.download_and_qc': { 'ncbi_datasets_util.download_and_qc.NcbiDataSummarizer': ( 'downloader_and_summarizer.html#ncbidatasummarizer',
                                                                                                               'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.NcbiDataSummarizer.get_files_from_data_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.get_files_from_data_folder',
                                                                                                                                          'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.NcbiDataSummarizer.get_files_from_isolate_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.get_files_from_isolate_folder',
                                                                                                                                             'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.NcbiDataSummarizer.summarize_data_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.summarize_data_folder',
                                                                                                                                     'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.NcbiDataSummarizer.summarize_fasta': ( 'downloader_and_summarizer.html#ncbidatasummarizer.summarize_fasta',
                                                                                                                               'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.cli': ( 'downloader_and_summarizer.html#cli',
                                                                                                'ncbi_datasets_util/download_and_qc.py'),
                                                    'ncbi_datasets_util.download_and_qc.get_files_from_data_folder': ( 'downloader_and_summarizer.html#get_files_from_data_folder',
                                                                                                                       'ncbi_datasets_util/download_and_qc.py')},
            'ncbi_datasets_util.downloader': { 'ncbi_datasets_util.downloader.cli': ( 'downloader.html#cli',
                                                                                      'ncbi_datasets_util/downloader.py'),
                                               'ncbi_datasets_util.downloader.download_genomes_from_summary': ( 'downloader.html#download_genomes_from_summary',
                                                                                                                'ncbi_datasets_util/downloader.py'),
                                               'ncbi_datasets_util.downloader.download_genomes_from_taxon': ( 'downloader.html#download_genomes_from_taxon',
                                                                                                              'ncbi_datasets_util/downloader.py'),
                                               'ncbi_datasets_util.downloader.download_summary': ( 'downloader.html#download_summary',
                                                                                                   'ncbi_datasets_util/downloader.py'),
                                               'ncbi_datasets_util.downloader.hello_world': ( 'downloader.html#hello_world',
                                                                                              'ncbi_datasets_util/downloader.py')},
            'ncbi_datasets_util.downloader_and_summarizer': { 'ncbi_datasets_util.downloader_and_summarizer.NcbiDataSummarizer': ( 'downloader_and_summarizer.html#ncbidatasummarizer',
                                                                                                                                   'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.NcbiDataSummarizer.get_files_from_data_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.get_files_from_data_folder',
                                                                                                                                                              'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.NcbiDataSummarizer.get_files_from_isolate_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.get_files_from_isolate_folder',
                                                                                                                                                                 'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.NcbiDataSummarizer.summarize_data_folder': ( 'downloader_and_summarizer.html#ncbidatasummarizer.summarize_data_folder',
                                                                                                                                                         'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.NcbiDataSummarizer.summarize_fasta': ( 'downloader_and_summarizer.html#ncbidatasummarizer.summarize_fasta',
                                                                                                                                                   'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.cli': ( 'downloader_and_summarizer.html#cli',
                                                                                                                    'ncbi_datasets_util/downloader_and_summarizer.py'),
                                                              'ncbi_datasets_util.downloader_and_summarizer.get_files_from_data_folder': ( 'downloader_and_summarizer.html#get_files_from_data_folder',
                                                                                                                                           'ncbi_datasets_util/downloader_and_summarizer.py')},
            'ncbi_datasets_util.hello_world': { 'ncbi_datasets_util.hello_world.cli': ( 'downloader.html#cli',
                                                                                        'ncbi_datasets_util/hello_world.py'),
                                                'ncbi_datasets_util.hello_world.hello_world': ( 'downloader.html#hello_world',
                                                                                                'ncbi_datasets_util/hello_world.py')},
            'ncbi_datasets_util.some_string': {},
            'ncbi_datasets_util.summarizer': { 'ncbi_datasets_util.summarizer.DnaSeq': ( 'summarizer.html#dnaseq',
                                                                                         'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.__add__': ( 'summarizer.html#dnaseq.__add__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.__init__': ( 'summarizer.html#dnaseq.__init__',
                                                                                                  'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.__iter__': ( 'summarizer.html#dnaseq.__iter__',
                                                                                                  'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.__len__': ( 'summarizer.html#dnaseq.__len__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.__repr__': ( 'summarizer.html#dnaseq.__repr__',
                                                                                                  'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.iupac_counts': ( 'summarizer.html#dnaseq.iupac_counts',
                                                                                                      'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.phred_score_to_int': ( 'summarizer.html#dnaseq.phred_score_to_int',
                                                                                                            'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.print_fasta': ( 'summarizer.html#dnaseq.print_fasta',
                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.reverse_complement': ( 'summarizer.html#dnaseq.reverse_complement',
                                                                                                            'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.DnaSeq.translate': ( 'summarizer.html#dnaseq.translate',
                                                                                                   'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta': ( 'summarizer.html#fasta',
                                                                                        'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.__init__': ( 'summarizer.html#fasta.__init__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.__iter__': ( 'summarizer.html#fasta.__iter__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.__len__': ( 'summarizer.html#fasta.__len__',
                                                                                                'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.__repr__': ( 'summarizer.html#fasta.__repr__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.concat_seq': ( 'summarizer.html#fasta.concat_seq',
                                                                                                   'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.from_file': ( 'summarizer.html#fasta.from_file',
                                                                                                  'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.iupac_counts': ( 'summarizer.html#fasta.iupac_counts',
                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fasta.write': ( 'summarizer.html#fasta.write',
                                                                                              'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq': ( 'summarizer.html#fastq',
                                                                                        'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.__init__': ( 'summarizer.html#fastq.__init__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.__iter__': ( 'summarizer.html#fastq.__iter__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.__len__': ( 'summarizer.html#fastq.__len__',
                                                                                                'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.__repr__': ( 'summarizer.html#fastq.__repr__',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.from_file': ( 'summarizer.html#fastq.from_file',
                                                                                                  'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.Fastq.write': ( 'summarizer.html#fastq.write',
                                                                                              'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.NcbiDataSummarizer': ( 'summarizer.html#ncbidatasummarizer',
                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.NcbiDataSummarizer.get_files_from_data_folder': ( 'summarizer.html#ncbidatasummarizer.get_files_from_data_folder',
                                                                                                                                'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.NcbiDataSummarizer.get_files_from_isolate_folder': ( 'summarizer.html#ncbidatasummarizer.get_files_from_isolate_folder',
                                                                                                                                   'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.NcbiDataSummarizer.summarize_data_folder': ( 'summarizer.html#ncbidatasummarizer.summarize_data_folder',
                                                                                                                           'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.NcbiDataSummarizer.summarize_fasta': ( 'summarizer.html#ncbidatasummarizer.summarize_fasta',
                                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinFasta': ( 'summarizer.html#proteinfasta',
                                                                                               'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinFasta.__init__': ( 'summarizer.html#proteinfasta.__init__',
                                                                                                        'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinFasta.from_file': ( 'summarizer.html#proteinfasta.from_file',
                                                                                                         'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq': ( 'summarizer.html#proteinseq',
                                                                                             'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.__add__': ( 'summarizer.html#proteinseq.__add__',
                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.__init__': ( 'summarizer.html#proteinseq.__init__',
                                                                                                      'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.__iter__': ( 'summarizer.html#proteinseq.__iter__',
                                                                                                      'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.__len__': ( 'summarizer.html#proteinseq.__len__',
                                                                                                     'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.__repr__': ( 'summarizer.html#proteinseq.__repr__',
                                                                                                      'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.ProteinSeq.print_to_file': ( 'summarizer.html#proteinseq.print_to_file',
                                                                                                           'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.SpadesAssembly': ( 'summarizer.html#spadesassembly',
                                                                                                 'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.SpadesAssembly.contig_stats': ( 'summarizer.html#spadesassembly.contig_stats',
                                                                                                              'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.SpadesAssembly.filter_contigs': ( 'summarizer.html#spadesassembly.filter_contigs',
                                                                                                                'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.cli': ( 'summarizer.html#cli',
                                                                                      'ncbi_datasets_util/summarizer.py'),
                                               'ncbi_datasets_util.summarizer.get_files_from_data_folder': ( 'summarizer.html#get_files_from_data_folder',
                                                                                                             'ncbi_datasets_util/summarizer.py')}}}
